@@ -35,8 +35,16 @@ import eventlet
 from eventlet.semaphore import Semaphore
 from neutron.agent import rpc as agent_rpc
 from neutron.common import topics
-from neutron import context as ctx
-from neutron.db import l3_db
+try:
+    from neutron_lib import context as ctx
+except ImportError:
+    # Neutron code prior to ca751a1486 (6th March 2017).
+    from neutron import context as ctx
+try:
+    from neutron.db.models.l3 import FloatingIP
+except ImportError:
+    # Ocata and earlier.
+    from neutron.db.l3_db import FloatingIP
 from neutron.db import models_v2
 from neutron.plugins.ml2 import driver_api as api
 from neutron.plugins.ml2.drivers import mech_agent
@@ -1305,7 +1313,8 @@ class CalicoMechanismDriver(mech_agent.SimpleAgentMechanismDriverBase):
             LOG.warning("Extra groups: %s", extra_groups)
 
         # First, create the missing security profiles.
-        self._resync_missing_profiles(context, missing_groups)
+        if missing_groups:
+            self._resync_missing_profiles(context, missing_groups)
 
         # Next, reconcile existing security profiles. This involves looping
         # over them, grabbing their data, and then comparing that to what
@@ -1332,7 +1341,7 @@ class CalicoMechanismDriver(mech_agent.SimpleAgentMechanismDriverBase):
         """
         with self._txn_from_context(context, tag="resync-prof-missing"):
             rules = self.db.get_security_group_rules(
-                context, filters={'security_group_id': missing_group_ids}
+                context, filters={'security_group_id': list(missing_group_ids)}
             )
 
             profiles_to_write = (
@@ -1441,7 +1450,7 @@ class CalicoMechanismDriver(mech_agent.SimpleAgentMechanismDriverBase):
             {'int_ip': ip['fixed_ip_address'],
              'ext_ip': ip['floating_ip_address']}
             for ip in context.session.query(
-                l3_db.FloatingIP
+                FloatingIP
             ).filter_by(
                 fixed_port_id=port['id']
             )
