@@ -39,6 +39,8 @@ sys.modules['neutron.agent.rpc'] = m_neutron.agent.rpc
 sys.modules['neutron.common'] = m_neutron.common
 sys.modules['neutron.common.exceptions'] = m_neutron.common.exceptions
 sys.modules['neutron.db'] = m_neutron.db
+sys.modules['neutron.db.models'] = m_neutron.db.models
+sys.modules['neutron.db.models.l3'] = m_neutron.db.models.l3
 sys.modules['neutron.openstack'] = m_neutron.openstack
 sys.modules['neutron.openstack.common'] = m_neutron.openstack.common
 sys.modules['neutron.openstack.common.db'] = m_neutron.openstack.common.db
